@@ -5,5 +5,5 @@ from camel_model.camel_model import CamelModel
 
 class ReplacementPart(CamelModel):
     name: str
-    reference: str
+    reference: Optional[str]
     observations: Optional[str]
